ExperimentUser class
Represents user context for experiment targeting
Constructors
Properties
- deviceId → String?
-
Device ID
final
-
groupProperties
→ Map<
String, Map< ?String, dynamic> > -
Group properties
final
-
groups
→ Map<
String, dynamic> ? -
Groups the user belongs to
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String?
-
User ID (persistent identifier)
final
-
userProperties
→ Map<
String, dynamic> ? -
Custom user properties for targeting
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serializes to JSON
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override